==> scala-2.1.2.tar.gz: scala/xml/dtd/ValidationException.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: ValidationException.scala 5889 2006-03-05 00:33:02Z mihaylov $


package scala.xml.dtd;


case class ValidationException( e:String ) extends Exception( e );

object MakeValidationException {
  def fromFixedAttribute( k: String, value: String, actual: String ) =
    ValidationException("value of attribute " + k + " FIXED to \""+value+"\", but document tries \""+actual+"\"");

  def fromNonEmptyElement() = {
    new ValidationException("element should be *empty*");
  }
  def fromUndefinedElement( label:String ) = 
    new ValidationException("element \""+ label +"\" not allowed here");

  def fromUndefinedAttribute( key:String ) = 
    new ValidationException("attribute " + key +" not allowed here" );

  def fromMissingAttribute( allKeys:scala.collection.Set[String] ) = {
    val sb = new StringBuffer();
    sb.append("missing value for REQUIRED attribute");
    if( allKeys.size > 1 ) sb.append('s');
    val it = allKeys.elements;
    while (it.hasNext) {
      sb.append('\'').append(it.next).append('\'') 
    }
    new ValidationException(sb.toString());
  }

  def fromMissingAttribute( key: String, tpe: String ) = {
    new ValidationException("missing value for REQUIRED attribute "+key+" of type "+tpe);
  }

}

==> scala-2.1.7.tar.gz: scala/xml/dtd/ValidationException.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: ValidationException.scala 8097 2006-07-11 15:15:02Z emir $


package scala.xml.dtd;

import scala.runtime.compat.StringBuilder

case class ValidationException( e:String ) extends Exception( e );

object MakeValidationException {
  def fromFixedAttribute( k: String, value: String, actual: String ) =
    ValidationException("value of attribute " + k + " FIXED to \""+value+"\", but document tries \""+actual+"\"");

  def fromNonEmptyElement() = {
    new ValidationException("element should be *empty*");
  }
  def fromUndefinedElement( label:String ) = 
    new ValidationException("element \""+ label +"\" not allowed here");

  def fromUndefinedAttribute( key:String ) = 
    new ValidationException("attribute " + key +" not allowed here" );

  def fromMissingAttribute( allKeys:scala.collection.Set[String] ) = {
    val sb = new StringBuilder();
    sb.append("missing value for REQUIRED attribute");
    if( allKeys.size > 1 ) sb.append('s');
    val it = allKeys.elements;
    while (it.hasNext) {
      sb.append('\'').append(it.next).append('\'') 
    }
    new ValidationException(sb.toString());
  }

  def fromMissingAttribute( key: String, tpe: String ) = {
    new ValidationException("missing value for REQUIRED attribute "+key+" of type "+tpe);
  }

}
